"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSafePropertyChain = void 0;
var tslib_1 = require("tslib");
/**
 * Safely searches for a chain of properties in an object.
 *
 * @param obj - The object to safe search in for the chain of properties.
 * @param propertyChain - The chain of properties, separated by a dot, to search for.
 * @param defaultReturn - The value to return if any of the intermediate or the final value is not
 * defined.
 *
 * @returns The value of the chain of properties, or the default return if any of the intermediate
 * values is not defined.
 */
function getSafePropertyChain(obj, propertyChain, defaultReturn) {
    var resolved = getChain.apply(void 0, tslib_1.__spreadArray([obj], propertyChain.split('.')));
    return resolved === undefined ? defaultReturn : resolved;
}
exports.getSafePropertyChain = getSafePropertyChain;
/**
 * Searches for the value of a list of property names inside the object.
 *
 * @param obj - The object to search in.
 * @param property - The current property to search for.
 * @param propertyChain - The remaining properties to search for.
 * @returns The value to search for, or `undefined` if any of the intermediate values is not
 * defined.
 */
function getChain(obj, property) {
    if (property === void 0) { property = ''; }
    var propertyChain = [];
    for (var _i = 2; _i < arguments.length; _i++) {
        propertyChain[_i - 2] = arguments[_i];
    }
    return obj == null && property
        ? undefined
        : !property
            ? obj
            : getChain.apply(void 0, tslib_1.__spreadArray([obj[property]], propertyChain));
}
//# sourceMappingURL=get-safe-property-chain.js.map